#include "Ultrasonic.h"
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128  // Ancho de la pantalla OLED en píxeles
#define SCREEN_HEIGHT 64  // Altura de la pantalla OLED en píxeles

#define OLED_RESET -1
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

const int TRIG = 1;
const int ECHO = 0;
int potenciometro = 2; //conexión del potenciómetro
int distance;
long duracion = 0;
float cm = 0;

Ultrasonic ultrasonic(TRIG, ECHO);

void setup() {
  Serial.begin(9600);

  // Inicializar la comunicación con la pantalla OLED
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("Error: No se pudo inicializar la pantalla OLED"));
    for(;;);
  }

  // Borrar la pantalla
  display.clearDisplay();

  pinMode(TRIG, OUTPUT);
  pinMode(ECHO, INPUT);
  pinMode(potenciometro, INPUT);
}

void loop () {
  // Inicia el sonar y envia un pin
  digitalWrite(TRIG, LOW);
  delayMicroseconds(2);
  digitalWrite(TRIG, HIGH);
  delayMicroseconds(5);
  digitalWrite(TRIG, LOW);

  duracion = pulseIn(ECHO, HIGH); // lee el tiempo en microsegundos hasta que el eco vuelve.
  cm = (duracion / 2) / 29.1; // Convertir el tiempo a distancia en cm

  // Obtener el valor del potenciómetro
  distance = analogRead(potenciometro) / 35;

  // Ajustar la distancia si es necesario
  cm -= distance;

  // Borrar la pantalla
  display.clearDisplay();

  // Mostrar el valor de la distancia en la pantalla OLED
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(30, 20);
  display.print(cm);

  // Actualizar la pantalla
  display.display();

  // Esperar un breve tiempo para evitar lecturas demasiado rápidas del potenciómetro
  delay(100);
}
